==> ejc-analysis-api-3.0.0-20230713.064616-73-sources.jar: com/ejianc/business/analysis/vo/ActualValueVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 实际产值利润情况分析表
 *
 * @author generator
 *
 */
public class ActualValueVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String createUserName; // 创建人名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long projectStatus; // 项目状态
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private BigDecimal yearActualCompleteValue; // 本年实际完成产值
    private BigDecimal yearResponsibilityCost; // 本年责任成本(万元)
    private BigDecimal yearRealCost; // 本年实际成本
    private BigDecimal yearActualProfit; // 本年实际利润
    private BigDecimal accumulateActualCompleteValue; // 开累实际完成产值
    private BigDecimal accumulateResponsibilityCost; // 开累责任成本(万元)
    private BigDecimal accumulateRealCost; // 开累实际成本
    private BigDecimal accumulateActualProfit; // 开累实际利润
    private BigDecimal yearProfitRate; // 当年利润率(%)
    private BigDecimal accumulateProfitRate; // 开累利润率(%)
    private BigDecimal yearReduceRate; // 当年降低率(%)
    private BigDecimal accumulateReduceRate; // 开累降低率(%)
    private BigDecimal undertakingBenefitsRate; // 承接效益率(%)
    private BigDecimal overallProfitMargin; // 整体上缴利润率(%)
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    private Date projectCreateTime; // 项目创建日期
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称

    private String costanalysisMonth; // 项目月度成本分析报告月份
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称


    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public BigDecimal getYearActualCompleteValue() {
        return yearActualCompleteValue;
    }

    public void setYearActualCompleteValue(BigDecimal yearActualCompleteValue) {
        this.yearActualCompleteValue = yearActualCompleteValue;
    }
    public BigDecimal getYearResponsibilityCost() {
        return yearResponsibilityCost;
    }

    public void setYearResponsibilityCost(BigDecimal yearResponsibilityCost) {
        this.yearResponsibilityCost = yearResponsibilityCost;
    }
    public BigDecimal getYearRealCost() {
        return yearRealCost;
    }

    public void setYearRealCost(BigDecimal yearRealCost) {
        this.yearRealCost = yearRealCost;
    }
    public BigDecimal getYearActualProfit() {
        return yearActualProfit;
    }

    public void setYearActualProfit(BigDecimal yearActualProfit) {
        this.yearActualProfit = yearActualProfit;
    }
    public BigDecimal getAccumulateActualCompleteValue() {
        return accumulateActualCompleteValue;
    }

    public void setAccumulateActualCompleteValue(BigDecimal accumulateActualCompleteValue) {
        this.accumulateActualCompleteValue = accumulateActualCompleteValue;
    }
    public BigDecimal getAccumulateResponsibilityCost() {
        return accumulateResponsibilityCost;
    }

    public void setAccumulateResponsibilityCost(BigDecimal accumulateResponsibilityCost) {
        this.accumulateResponsibilityCost = accumulateResponsibilityCost;
    }
    public BigDecimal getAccumulateRealCost() {
        return accumulateRealCost;
    }

    public void setAccumulateRealCost(BigDecimal accumulateRealCost) {
        this.accumulateRealCost = accumulateRealCost;
    }
    public BigDecimal getAccumulateActualProfit() {
        return accumulateActualProfit;
    }

    public void setAccumulateActualProfit(BigDecimal accumulateActualProfit) {
        this.accumulateActualProfit = accumulateActualProfit;
    }
    public BigDecimal getYearProfitRate() {
        return yearProfitRate;
    }

    public void setYearProfitRate(BigDecimal yearProfitRate) {
        this.yearProfitRate = yearProfitRate;
    }
    public BigDecimal getAccumulateProfitRate() {
        return accumulateProfitRate;
    }

    public void setAccumulateProfitRate(BigDecimal accumulateProfitRate) {
        this.accumulateProfitRate = accumulateProfitRate;
    }
    public BigDecimal getYearReduceRate() {
        return yearReduceRate;
    }

    public void setYearReduceRate(BigDecimal yearReduceRate) {
        this.yearReduceRate = yearReduceRate;
    }
    public BigDecimal getAccumulateReduceRate() {
        return accumulateReduceRate;
    }

    public void setAccumulateReduceRate(BigDecimal accumulateReduceRate) {
        this.accumulateReduceRate = accumulateReduceRate;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public String getCostanalysisMonth() {
        return costanalysisMonth;
    }

    public void setCostanalysisMonth(String costanalysisMonth) {
        this.costanalysisMonth = costanalysisMonth;
    }

    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }

    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }

    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }
}

==> ejc-analysis-api-3.0.0-20230906.073819-132-sources.jar: com/ejianc/business/analysis/vo/ActualValueVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 实际产值利润情况分析表
 *
 * @author generator
 *
 */
public class ActualValueVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long projectStatus; // 项目状态
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private BigDecimal yearActualCompleteValue; // 本年实际完成产值
    private BigDecimal yearResponsibilityCost; // 本年责任成本(万元)
    private BigDecimal yearRealCost; // 本年实际成本
    private BigDecimal yearActualProfit; // 本年实际利润
    private BigDecimal accumulateActualCompleteValue; // 开累实际完成产值
    private BigDecimal accumulateResponsibilityCost; // 开累责任成本(万元)
    private BigDecimal accumulateRealCost; // 开累实际成本
    private BigDecimal accumulateActualProfit; // 开累实际利润
    private BigDecimal yearProfitRate; // 当年利润率(%)
    private BigDecimal accumulateProfitRate; // 开累利润率(%)
    private BigDecimal yearReduceRate; // 当年降低率(%)
    private BigDecimal accumulateReduceRate; // 开累降低率(%)
    private BigDecimal undertakingBenefitsRate; // 承接效益率(%)
    private BigDecimal overallProfitMargin; // 整体上缴利润率(%)
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    private Date projectCreateTime; // 项目创建日期
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称

    private String costanalysisMonth; // 项目月度成本分析报告月份
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public BigDecimal getYearActualCompleteValue() {
        return yearActualCompleteValue;
    }

    public void setYearActualCompleteValue(BigDecimal yearActualCompleteValue) {
        this.yearActualCompleteValue = yearActualCompleteValue;
    }
    public BigDecimal getYearResponsibilityCost() {
        return yearResponsibilityCost;
    }

    public void setYearResponsibilityCost(BigDecimal yearResponsibilityCost) {
        this.yearResponsibilityCost = yearResponsibilityCost;
    }
    public BigDecimal getYearRealCost() {
        return yearRealCost;
    }

    public void setYearRealCost(BigDecimal yearRealCost) {
        this.yearRealCost = yearRealCost;
    }
    public BigDecimal getYearActualProfit() {
        return yearActualProfit;
    }

    public void setYearActualProfit(BigDecimal yearActualProfit) {
        this.yearActualProfit = yearActualProfit;
    }
    public BigDecimal getAccumulateActualCompleteValue() {
        return accumulateActualCompleteValue;
    }

    public void setAccumulateActualCompleteValue(BigDecimal accumulateActualCompleteValue) {
        this.accumulateActualCompleteValue = accumulateActualCompleteValue;
    }
    public BigDecimal getAccumulateResponsibilityCost() {
        return accumulateResponsibilityCost;
    }

    public void setAccumulateResponsibilityCost(BigDecimal accumulateResponsibilityCost) {
        this.accumulateResponsibilityCost = accumulateResponsibilityCost;
    }
    public BigDecimal getAccumulateRealCost() {
        return accumulateRealCost;
    }

    public void setAccumulateRealCost(BigDecimal accumulateRealCost) {
        this.accumulateRealCost = accumulateRealCost;
    }
    public BigDecimal getAccumulateActualProfit() {
        return accumulateActualProfit;
    }

    public void setAccumulateActualProfit(BigDecimal accumulateActualProfit) {
        this.accumulateActualProfit = accumulateActualProfit;
    }
    public BigDecimal getYearProfitRate() {
        return yearProfitRate;
    }

    public void setYearProfitRate(BigDecimal yearProfitRate) {
        this.yearProfitRate = yearProfitRate;
    }
    public BigDecimal getAccumulateProfitRate() {
        return accumulateProfitRate;
    }

    public void setAccumulateProfitRate(BigDecimal accumulateProfitRate) {
        this.accumulateProfitRate = accumulateProfitRate;
    }
    public BigDecimal getYearReduceRate() {
        return yearReduceRate;
    }

    public void setYearReduceRate(BigDecimal yearReduceRate) {
        this.yearReduceRate = yearReduceRate;
    }
    public BigDecimal getAccumulateReduceRate() {
        return accumulateReduceRate;
    }

    public void setAccumulateReduceRate(BigDecimal accumulateReduceRate) {
        this.accumulateReduceRate = accumulateReduceRate;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public String getCostanalysisMonth() {
        return costanalysisMonth;
    }

    public void setCostanalysisMonth(String costanalysisMonth) {
        this.costanalysisMonth = costanalysisMonth;
    }

    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }

    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }

    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }
}
